# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .alert import *
from .alert_target import *
from .cloud_integration_app_dynamics import *
from .cloud_integration_aws_external_id import *
from .cloud_integration_azure import *
from .cloud_integration_azure_activity_log import *
from .cloud_integration_cloud_trail import *
from .cloud_integration_cloud_watch import *
from .cloud_integration_ec2 import *
from .cloud_integration_gcp import *
from .cloud_integration_gcp_billing import *
from .cloud_integration_new_relic import *
from .dashboard import *
from .dashboard_json import *
from .derived_metric import *
from .event import *
from .external_link import *
from .get_alert import *
from .get_alerts import *
from .get_dashboard import *
from .get_dashboards import *
from .get_default_user_group import *
from .get_derived_metric import *
from .get_derived_metrics import *
from .get_event import *
from .get_events import *
from .get_external_link import *
from .get_external_links import *
from .get_maintenance_window import *
from .get_maintenance_window_all import *
from .get_metrics_policy import *
from .get_role import *
from .get_roles import *
from .get_user import *
from .get_user_group import *
from .get_user_groups import *
from .get_users import *
from .ingestion_policy import *
from .maintenance_window import *
from .metrics_policy import *
from .provider import *
from .role import *
from .service_account import *
from .user import *
from .user_group import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_wavefront.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_wavefront.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "wavefront",
  "mod": "index/alert",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/alert:Alert": "Alert"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/alertTarget",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/alertTarget:AlertTarget": "AlertTarget"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationAppDynamics",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationAppDynamics:CloudIntegrationAppDynamics": "CloudIntegrationAppDynamics"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationAwsExternalId",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationAwsExternalId:CloudIntegrationAwsExternalId": "CloudIntegrationAwsExternalId"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationAzure",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationAzure:CloudIntegrationAzure": "CloudIntegrationAzure"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationAzureActivityLog",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationAzureActivityLog:CloudIntegrationAzureActivityLog": "CloudIntegrationAzureActivityLog"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationCloudTrail",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationCloudTrail:CloudIntegrationCloudTrail": "CloudIntegrationCloudTrail"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationCloudWatch",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationCloudWatch:CloudIntegrationCloudWatch": "CloudIntegrationCloudWatch"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationEc2",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationEc2:CloudIntegrationEc2": "CloudIntegrationEc2"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationGcp",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationGcp:CloudIntegrationGcp": "CloudIntegrationGcp"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationGcpBilling",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationGcpBilling:CloudIntegrationGcpBilling": "CloudIntegrationGcpBilling"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/cloudIntegrationNewRelic",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/cloudIntegrationNewRelic:CloudIntegrationNewRelic": "CloudIntegrationNewRelic"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/dashboard",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/dashboard:Dashboard": "Dashboard"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/dashboardJson",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/dashboardJson:DashboardJson": "DashboardJson"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/derivedMetric",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/derivedMetric:DerivedMetric": "DerivedMetric"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/event",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/event:Event": "Event"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/externalLink",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/externalLink:ExternalLink": "ExternalLink"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/ingestionPolicy",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/ingestionPolicy:IngestionPolicy": "IngestionPolicy"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/maintenanceWindow",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/maintenanceWindow:MaintenanceWindow": "MaintenanceWindow"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/metricsPolicy",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/metricsPolicy:MetricsPolicy": "MetricsPolicy"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/role",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/role:Role": "Role"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/serviceAccount",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/serviceAccount:ServiceAccount": "ServiceAccount"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/user",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/user:User": "User"
  }
 },
 {
  "pkg": "wavefront",
  "mod": "index/userGroup",
  "fqn": "pulumi_wavefront",
  "classes": {
   "wavefront:index/userGroup:UserGroup": "UserGroup"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "wavefront",
  "token": "pulumi:providers:wavefront",
  "fqn": "pulumi_wavefront",
  "class": "Provider"
 }
]
"""
)
